apiVersion: extensions/v1beta1
kind: Deployment
metadata:
  labels:
    app: app
    revision: "${REVISION}"
  name: app
  namespace: ${NAMESPACE}
spec:
  replicas: 2
  revisionHistoryLimit: 2
  strategy:
    type: RollingUpdate
  minReadySeconds: 5
  selector:
    matchLabels:
      app: app
  template:
    metadata:
      namespace: ${NAMESPACE}
      labels:
        app: app
        revision: "${REVISION}"
    spec:
      imagePullSecrets:
      - name: registry-access
      volumes:
      - name: ssh-config
        secret:
          secretName: ssh-config
          items:
          - key: "id_rsa"
            path: ./id_rsa
            mode: 0600
          - key: "id_rsa.pub"
            path: ./id_rsa.pub
            mode: 0644
      containers:
      - name: app
        image: ${DOCKER_REGISTRY}/${IMAGE_NAME}:${IMAGE_TAG}
        imagePullPolicy: Always
        readinessProbe:
          httpGet:
            port: 8000
            path: /_status/ping
            httpHeaders:
              - name: Host
                value: ${DOMAIN}
          initialDelaySeconds: 5
          periodSeconds: 10
          timeoutSeconds: 5
        ports:
          - containerPort: 8000
            protocol: TCP
        volumeMounts:
          - name: ssh-config
            readOnly: true
            mountPath: /home/ubuntu/.secrets/ssh-config
        env:
          # config
          - name: ADMINAUDIT_EMAILS_RECIPIENTS
            valueFrom:
              configMapKeyRef:
                name: app
                key: ADMINAUDIT_EMAILS_RECIPIENTS
          - name: ALLOWED_HOSTS
            valueFrom:
              configMapKeyRef:
                name: app
                key: ALLOWED_HOSTS
          - name: BRANCH_CACHE_DIR
            valueFrom:
              configMapKeyRef:
                name: app
                key: BRANCH_CACHE_DIR
          - name: DJANGO_SETTINGS_MODULE
            value: django_project.settings_base
          - name: GIT_SSH_DEFAULT_PORT
            valueFrom:
              configMapKeyRef:
                name: app
                key: GIT_SSH_DEFAULT_PORT
          - name: GIT_SSH_DEFAULT_USERNAME
            valueFrom:
              configMapKeyRef:
                name: app
                key: GIT_SSH_DEFAULT_USERNAME
          - name: METRICS_PREFIX
            valueFrom:
              configMapKeyRef:
                name: app
                key: METRICS_PREFIX
          - name: METRICS_TARGET
            valueFrom:
              configMapKeyRef:
                name: app
                key: METRICS_TARGET
          - name: OOPS_REPORTER
            valueFrom:
              configMapKeyRef:
                name: app
                key: OOPS_REPORTER
          - name: OPENID_SSO_SERVER_URL
            valueFrom:
              configMapKeyRef:
                name: app
                key: OPENID_SSO_SERVER_URL
          - name: USE_HTTPS
            valueFrom:
              configMapKeyRef:
                name: app
                key: USE_HTTPS
          - name: WORKERS
            valueFrom:
              configMapKeyRef:
                name: app
                key: WORKERS
          # secrets
          - name: CELERY_BROKER_URL
            valueFrom:
              secretKeyRef:
                name: app
                key: CELERY_BROKER_URL
          - name: ADMIN_DATABASE_URL
            valueFrom:
              secretKeyRef:
                name: app
                key: ADMIN_DATABASE_URL
          - name: DATABASE_URL
            valueFrom:
              secretKeyRef:
                name: app
                key: DATABASE_URL
          - name: SECRET_KEY
            valueFrom:
              secretKeyRef:
                name: app
                key: SECRET_KEY
      - name: worker
        image: ${DOCKER_REGISTRY}/${IMAGE_NAME}:${IMAGE_TAG}
        imagePullPolicy: Always
        volumeMounts:
          - name: ssh-config
            readOnly: true
            mountPath: /home/ubuntu/.secrets/ssh-config
        env:
          # config
          - name: ADMINAUDIT_EMAILS_RECIPIENTS
            valueFrom:
              configMapKeyRef:
                name: app
                key: ADMINAUDIT_EMAILS_RECIPIENTS
          - name: ALLOWED_HOSTS
            valueFrom:
              configMapKeyRef:
                name: app
                key: ALLOWED_HOSTS
          - name: BRANCH_CACHE_DIR
            valueFrom:
              configMapKeyRef:
                name: app
                key: BRANCH_CACHE_DIR
          - name: DJANGO_SETTINGS_MODULE
            value: django_project.settings_base
          - name: GIT_SSH_DEFAULT_PORT
            valueFrom:
              configMapKeyRef:
                name: app
                key: GIT_SSH_DEFAULT_PORT
          - name: GIT_SSH_DEFAULT_USERNAME
            valueFrom:
              configMapKeyRef:
                name: app
                key: GIT_SSH_DEFAULT_USERNAME
          - name: METRICS_PREFIX
            valueFrom:
              configMapKeyRef:
                name: app
                key: METRICS_PREFIX
          - name: METRICS_TARGET
            valueFrom:
              configMapKeyRef:
                name: app
                key: METRICS_TARGET
          - name: OOPS_REPORTER
            valueFrom:
              configMapKeyRef:
                name: app
                key: OOPS_REPORTER
          - name: OPENID_SSO_SERVER_URL
            valueFrom:
              configMapKeyRef:
                name: app
                key: OPENID_SSO_SERVER_URL
          - name: USE_HTTPS
            valueFrom:
              configMapKeyRef:
                name: app
                key: USE_HTTPS
          - name: WORKERS
            valueFrom:
              configMapKeyRef:
                name: app
                key: WORKERS
          # secrets
          - name: CELERY_BROKER_URL
            valueFrom:
              secretKeyRef:
                name: app
                key: CELERY_BROKER_URL
          - name: ADMIN_DATABASE_URL
            valueFrom:
              secretKeyRef:
                name: app
                key: ADMIN_DATABASE_URL
          - name: DATABASE_URL
            valueFrom:
              secretKeyRef:
                name: app
                key: DATABASE_URL
          - name: SECRET_KEY
            valueFrom:
              secretKeyRef:
                name: app
                key: SECRET_KEY
        command: ["make", "worker"]
        lifecycle:
          postStart:
            exec:
              command: ["/bin/sh", "-c", "mkdir -p ~/.ssh && \
                                          ln -sf ~/.secrets/ssh-config/id_rsa ~/.ssh/id_rsa && \
                                          ln -sf ~/.secrets/ssh-config/id_rsa.pub ~/.ssh/id_rsa.pub && \
                                          /usr/src/app/scripts/setup-bzr ${LP_BOT}"]
      securityContext:
        runAsNonRoot: true
        runAsUser: 1000
        fsGroup: 1000
