REGISTRY_CONFIG = config/devel/registry.yaml

.PHONY: cluster
cluster:  ## Bootstrap k8s cluster
	minikube start --vm-driver=kvm
	kubectl create -f $(REGISTRY_CONFIG) || kubectl apply -f $(REGISTRY_CONFIG)

.PHONY: registry-proxy
registry-proxy: REGISTRY_POD=$(shell kubectl get pods --namespace kube-system -l k8s-app=kube-registry-upstream \
							 -o template --template '{{range .items}}{{.metadata.name}} {{.status.phase}}{{"\n"}}{{end}}' \
							 | grep Running | head -1 | cut -f1 -d' ')
registry-proxy:  ## Run registry proxy
	kubectl -n kube-system port-forward $(REGISTRY_POD) 5000:5000

.PHONY: external-services
external-services: tmp/namespace-dev.yaml tmp/services-dev.yaml  ## Deploy "external" services for development
	@$(check-env-vars)
	kubectl apply -f tmp/namespace-dev.yaml --record
	kubectl apply -f tmp/services-dev.yaml --record

.PHONY: clean-namespaces
clean-namespaces:
	@$(check-env-vars)
	-kubectl delete ns $(NAMESPACE) $(NAMESPACE)-dev

.PHONY: clean-secrets
clean-secrets:
	rm -f secrets.yaml

.PHONY: clean
clean: clean-namespaces clean-config clean-secrets

# helper targets

tmp/%-dev.yaml: config/devel/%.yaml.tpl
	$(MAKE) render-template SRC=$< DST=$@

secrets.yaml: secrets.yaml.tpl
	$(MAKE) render-template SRC=$< DST=$@
